import { aws_appsync, aws_iam } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { BaseApi, BaseApiProps } from './base-api';
import { LambdaFunction } from './func';
export interface GraphQlApiProps extends BaseApiProps {
    definitionFileName: string;
}
export interface VtlResolverOptions {
    /**
     * The datasource the VTL resolver targets
     */
    dataSource: aws_appsync.BaseDataSource;
    /**
     * string replacements to process on the VTL
     *
     * @default no variable expansions
     */
    variables?: {
        [name: string]: string;
    };
}
export interface JsResolverOptions {
    /**
     * Variables that will be put into the "stash" of the resolver pipeline
     *
     * @default none
     */
    readonly stashValues?: {
        [key: string]: string;
    };
    /**
     * name of the pipeline steps to create
     *
     * @default - only a default step will be created
     */
    readonly pipelineStepNames?: string[];
}
export declare class GraphQlApi<RESOLVERS> extends BaseApi {
    private props;
    readonly api: aws_appsync.GraphqlApi;
    readonly tableDataSource?: aws_appsync.DynamoDbDataSource;
    private _functions;
    private cognitoAuth;
    constructor(scope: Construct, id: string, props: GraphQlApiProps);
    /**
     *
     */
    grantAccess<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(grantee: aws_iam.IGrantable, typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     *
     */
    grantAccessUnAuth<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     *
     */
    grantAccessAuth<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     * getFunctionForOperation
     */
    getFunctionForOperation<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE): LambdaFunction;
    addLambdaResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE): LambdaFunction;
    addDynamoDbVtlResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options?: Omit<VtlResolverOptions, 'dataSource'>): void;
    addDynamoDbJSResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options?: JsResolverOptions): void;
    addJSResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, dataSource: aws_appsync.BaseDataSource, options?: JsResolverOptions): void;
    addVtlResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options: VtlResolverOptions): void;
    private substVariables;
    private createEntryFile;
    private createJSResolverFile;
}
